@@ -2,15 +2,19 @@ use v5.14;
 use warnings;
 
 package Pantry::App::Command;
-# ABSTRACT: Implements common command options
-our $VERSION = '0.001'; # VERSION
+# ABSTRACT: Pantry command superclass
+our $VERSION = '0.002'; # VERSION
 
 use App::Cmd::Setup -command;
 
 sub opt_spec {
   my ($class, $app) = @_;
     return (
+    # Universal
     [ 'help' => "This usage screen" ],
+    # Selectors/qualifiers
+    [ 'recipe|r=s@' => "A recipe" ],
+    [ 'default|d=s@' => "Default attribute" ],
     $class->options($app),
   )
 }
@@ -21,8 +25,16 @@ sub validate_args {
   $self->validate( $opt, $args );
 }
 
+sub pantry {
+  my $self = shift;
+  require Pantry::Model::Pantry;
+  $self->{pantry} ||= Pantry::Model::Pantry->new;
+  return $self->{pantry};
+}
+
 1;
 
+
 # vim: ts=2 sts=2 sw=2 et:
 
 __END__
@@ -30,11 +42,18 @@ __END__
 
 =head1 NAME
 
-Pantry::App::Command - Implements common command options
+Pantry::App::Command - Pantry command superclass
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 DESCRIPTION
+
+This internal implementation class defines common command line options
+and provides methods needed by all command subclasses.
+
+=for Pod::Coverage pantry
 
 =head1 AUTHOR
 
