@@ -3,14 +3,10 @@ use warnings;
 
 package Pantry::App::Command::create;
 # ABSTRACT: Implements pantry create subcommand
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use Pantry::App -command;
 use autodie;
-use File::Basename qw/dirname/;
-use File::Path qw/mkpath/;
-use File::Slurp qw/write_file/;
-use JSON;
 
 use namespace::clean;
 
@@ -38,9 +34,6 @@ sub validate {
   if ( ! length $name ) {
     $self->usage_error( "This command requires the name for the thing to create" );
   }
-  elsif ( -e $self->app->node_path($name) ) {
-    $self->usage_error( "Node '$name' already exists" );
-  }
 
   return;
 }
@@ -49,35 +42,20 @@ sub execute {
   my ($self, $opt, $args) = @_;
 
   my ($type, $name) = splice(@$args, 0, 2);
-  my $path = $self->app->node_path($name);
-  my $data = $self->_node_guts($name);
-  mkpath( dirname($path) );
-  write_file( $path, { no_clobber => 1, binmode => ":raw" }, $data );
+
+  if ( $type eq 'node' ) {
+    my $node = $self->pantry->node( $name );
+    if ( -e $node->path ) {
+      $self->usage_error( "Node '$name' already exists" );
+    }
+    else {
+      $node->save;
+    }
+  }
+
   return;
 }
 
-#--------------------------------------------------------------------------#
-# Internal
-#--------------------------------------------------------------------------#
-
-sub _node_guts {
-  my ($self, $name) = @_;
-
-  my $data = {
-    name => $name,
-    default => {},
-    override => {},
-    normal => {},
-    automatic => {},
-    run_list => [],
-  };
-
-  my $json = eval {JSON->new->pretty(1)->utf8(1)->encode($data)};
-  die "JSON encoding error: $@\n" if $@;
-
-  return $json;
-}
-
 1;
 
 
@@ -92,7 +70,16 @@ Pantry::App::Command::create - Implements pantry create subcommand
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 SYNOPSIS
+
+  $ pantry create node foo.example.com
+
+=head1 DESCRIPTION
+
+This class implements the C<pantry create> command, which is used to create a new node data file
+in a pantry.
 
 =for Pod::Coverage options validate
 
