@@ -3,15 +3,14 @@ use warnings;
 
 package Pantry::App::Command::edit;
 # ABSTRACT: Implements pantry edit subcommand
-our $VERSION = '0.001'; # VERSION
+our $VERSION = '0.002'; # VERSION
 
 use Pantry::App -command;
 use autodie;
-use File::Basename qw/dirname/;
-use File::Path qw/mkpath/;
-use File::Slurp qw/write_file/;
+use File::Basename qw/dirname basename/;
+use File::Slurp qw/read_file/;
 use IPC::Cmd qw/can_run/;
-use JSON;
+use JSON qw/decode_json/;
 
 use namespace::clean;
 
@@ -39,9 +38,6 @@ sub validate {
   if ( ! length $name ) {
     $self->usage_error( "This command requires the name for the thing to edit" );
   }
-  elsif ( ! -e $self->app->node_path($name) ) {
-    $self->usage_error( "Node '$name' does not exist" );
-  }
 
   return;
 }
@@ -50,7 +46,6 @@ sub execute {
   my ($self, $opt, $args) = @_;
 
   my ($type, $name) = splice(@$args, 0, 2);
-  my $path = $self->app->node_path($name);
 
   my @editor = defined $ENV{EDITOR} ? split / /, $ENV{EDITOR} : ();
   if ( @editor ) {
@@ -58,7 +53,7 @@ sub execute {
   }
 
   if ( @editor ) {
-    system( @editor, $path ) and die "System failed!: $!";
+    $self->_edit_file($name, @editor);
   }
   else {
     $self->usage_error( "EDITOR not set or not found" );
@@ -71,24 +66,20 @@ sub execute {
 # Internal
 #--------------------------------------------------------------------------#
 
-sub _node_guts {
-  my ($self, $name) = @_;
-
-  my $data = {
-    name => $name,
-    json_class => "Chef::Node",
-    chef_type => "node",
-    default => {},
-    override => {},
-    normal => {},
-    automatic => {},
-    run_list => [],
-  };
-
-  my $json = eval {JSON->new->pretty(1)->utf8(1)->encode($data)};
-  die "JSON encoding error: $@\n" if $@;
-
-  return $json;
+sub _edit_file {
+  my ($self, $name, @editor) = @_;
+  my $path = $self->pantry->node($name)->path;
+  if ( -e $path ) {
+    system( @editor, $path ) and die "System failed!: $!";
+    eval { decode_json(read_file($path,{ binmode => ":raw" })) };
+    if ( my $err = $@ ) {
+      $err =~ s/, at .* line .*//;
+      warn "Warning: JSON errors in config for $name\n";
+    }
+  }
+  else {
+    $self->usage_error("Node '$name' does not exist");
+  }
 }
 
 1;
@@ -105,7 +96,16 @@ Pantry::App::Command::edit - Implements pantry edit subcommand
 
 =head1 VERSION
 
-version 0.001
+version 0.002
+
+=head1 SYNOPSIS
+
+  $ pantry edit node foo.example.com
+
+=head1 DESCRIPTION
+
+This class implements the C<pantry edit> command, which is used to open the node data
+JSON file in an editor for direct editing.
 
 =for Pod::Coverage options validate
 
